@@ -6,6 +6,7 @@
 """
 task names
 """
+import os
 import os.path
 
 global REC_RESERVE
@@ -68,8 +69,16 @@ REC_AUTO_SUGGEST_AP2FP = "auto_suggest_ap2fp"
 REC_AUTO_KEYWORD = "auto_keyword"
 REC_BAYES_SUGGEST ="bayes_suggest"
 
+version = 94
 def printutf8(unicode):
-    print unicode.encode('utf-8')
+    str=unicode.encode('utf-8')
+    print str
+    logfname="/var/log/rec10"
+    mode="a"
+    if os.path.exists(logfname):
+        f=open(logfname,mode)
+        f.write(str+"\n")
+        f.close()
 def addlog(tspath,txt,log_title):
     logo=tspath
     logo=logo.replace("_1.wav",".ts")
@@ -93,11 +102,11 @@ def addlog(tspath,txt,log_title):
     f=open(logo,'a')
     s=len(txt)
     stxt=""
-    if s>1400:
-        stxt=txt[0:700]+"\n\n(ry..)\n"
-        st=txt[s-700:].find("\n")
+    if s>1600:
+        stxt=txt[0:800]+"\n\n(ry..)\n"
+        st=txt[s-800:].find("\n")
         if st>0:
-            stxt=stxt+txt[s-700+st:]
+            stxt=stxt+txt[s-800+st:]
     else:
         stxt=txt
     txtw="\n####"+log_title+"####\n"+stxt
